@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
+
 # ======================================================================================================================
-#  Copyright (©) 2015-2020 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.                                  =
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory                         =
+#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
 # ======================================================================================================================
 
-__all__ = ['get_user_and_node',
-           'get_user',
-           'get_node',
-           'is_kernel',
-           'sh'
-           ]
+__all__ = [
+    "get_user_and_node",
+    "get_user",
+    "get_node",
+    "is_kernel",
+    "sh",
+    "is_windows",
+]
 
 import getpass
 import platform
@@ -17,6 +20,11 @@ import sys
 from subprocess import run, PIPE, STDOUT
 
 
+def is_windows():
+    win = "Windows" in platform.platform()
+    return win
+
+
 def get_user():
     return getpass.getuser()
 
@@ -30,30 +38,29 @@ def get_user_and_node():
 
 
 def is_kernel():
-    """ Check if we are running from IPython
-
+    """
+    Check if we are running from IPython.
     """
     # from http://stackoverflow.com
     # /questions/34091701/determine-if-were-in-an-ipython-notebook-session
-    if 'IPython' not in sys.modules:
+    if "IPython" not in sys.modules:
         # IPython hasn't been imported
-        return False
+        return False  # pragma: no cover
     from IPython import get_ipython  # pragma: no cover
+
     # check for `kernel` attribute on the IPython instance
-    return getattr(get_ipython(), 'kernel', None) is not None  # pragma: no cover
+    return getattr(get_ipython(), "kernel", None) is not None  # pragma: no cover
 
 
-class _ExecCommand():
+class _ExecCommand:
+    """
+    Parameters
+    ----------
+    command : shell command to execute
+    """
 
     def __init__(self, command):
-        """
 
-        Parameters
-        ----------
-        command: shell command to execute
-        perror: error management
-
-        """
         self.commands = [command]
 
     def __call__(self, *args, **kwargs):
@@ -61,7 +68,9 @@ class _ExecCommand():
         self.commands.extend(args)
 
         silent = kwargs.pop("silent", False)
-        proc = run(self.commands, text=True, stdout=PIPE, stderr=STDOUT)  # capture_output=True)
+        proc = run(
+            self.commands, text=True, stdout=PIPE, stderr=STDOUT
+        )  # capture_output=True)
 
         # TODO: handle error codes
         if not silent and proc.stdout:
@@ -69,10 +78,10 @@ class _ExecCommand():
         return proc.stdout
 
 
+# noinspection PyPep8Naming
 class sh(object):
     """
-    Utility to run subprocess run command as if they were functions
-
+    Utility to run subprocess run command as if they were functions.
     """
 
     def __getattr__(self, command):
